@@ -29,6 +29,7 @@
 #include <Lum/Model/Calendar.h>
 #include <Lum/Model/Integer.h>
 #include <Lum/Model/String.h>
+#include <Lum/Model/Time.h>
 
 typedef signed long Value;
 
@@ -92,6 +93,7 @@ public:
 extern Data                      data;
 
 extern Lum::Model::CalendarRef   date;
+extern Lum::Model::TimeRef       timestamp;
 
 extern Lum::Model::SizeTRef      currentTab;
 
