@@ -315,12 +315,12 @@ void DataInput::CalcSize()
 
   ds->AddSpace(true)
     ->Add(Lum::Button::Create(L"+",
-                              Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::addStockImage),
+                              Lum::OS::Theme::imageAdd,
                               addWeightAction,
                               Lum::Button::typeIcon))
     ->Add(new Lum::HSpace(Lum::Space::sizeSmall))
     ->Add(Lum::Button::Create(L"-",
-                              Lum::OS::display->GetTheme()->GetStockImage(Lum::OS::Theme::removeStockImage),
+                              Lum::OS::Theme::imageRemove,
                               removeItemAction,
                               Lum::Button::typeIcon));
 
