@@ -25,7 +25,6 @@
 #include <Lum/Combo.h>
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/String.h>
 #include <Lum/Tab.h>
 #include <Lum/Text.h>
@@ -84,7 +83,6 @@ Preferences::~Preferences()
 
 void Preferences::PreInit()
 {
-  Lum::ButtonRow            *buttonRow;
   Lum::Combo                *combo;
   Lum::Label                *label;
   Lum::Panel                *panel,*panel2;
@@ -96,23 +94,13 @@ void Preferences::PreInit()
 
   tab=new Lum::Tab();
 
-  label=new Lum::Label();
-  label->SetFlex(true,true);
-
-  string=new Lum::String();
-  string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
-  string->SetModel(valueUnit);
-  label->AddLabel(_(L"PREFS_LABEL_VALUE_UNIT",L"Value unit:"),string);
-
-  string=new Lum::String();
-  string->SetMinWidth(Lum::Base::Size::stdCharWidth,10);
-  string->SetModel(weightUnit);
-  label->AddLabel(_(L"PREFS_LABEL_WEIGHT_UNIT",L"Weight unit:"),string);
+  label=Lum::Label::Create(true,true);
+  label->AddLabel(_(L"PREFS_LABEL_VALUE_UNIT",L"Value unit:"),Lum::String::Create(valueUnit,10u));
+  label->AddLabel(_(L"PREFS_LABEL_WEIGHT_UNIT",L"Weight unit:"),Lum::String::Create(weightUnit,10u));
 
   tab->Add(_(L"PREFS_LABEL_UNITS",L"Units"),label);
 
-  label=new Lum::Label();
-  label->SetFlex(true,true);
+  label=Lum::Label::Create(true,true);
 
   panel2=new Lum::HPanel();
 
@@ -123,9 +111,9 @@ void Preferences::PreInit()
   string->SetModel(bottomWeight);
   panel2->Add(string);
 
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
   panel2->Add(new Lum::Text(L"-"));
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
@@ -136,7 +124,7 @@ void Preferences::PreInit()
 
   label->AddLabel(_(L"PREFS_LABEL_WEIGHT_GRAPH",L"Shown weight interval:"),panel2);
 
-  panel2=new Lum::HPanel();
+  panel2=Lum::HPanel::Create();
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
@@ -145,9 +133,9 @@ void Preferences::PreInit()
   string->SetModel(minWeight);
   panel2->Add(string);
 
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
   panel2->Add(new Lum::Text(L"-"));
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
@@ -159,10 +147,9 @@ void Preferences::PreInit()
 
   tab->Add(_(L"PREFS_LABEL_WEIGHTS",L"Weights"),label);
 
-  label=new Lum::Label();
-  label->SetFlex(true,true);
+  label=Lum::Label::Create(true,true);
 
-  panel2=new Lum::HPanel();
+  panel2=Lum::HPanel::Create();
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
@@ -171,9 +158,9 @@ void Preferences::PreInit()
   string->SetModel(bottomValue);
   panel2->Add(string);
 
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
   panel2->Add(new Lum::Text(L"-"));
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
@@ -193,9 +180,9 @@ void Preferences::PreInit()
   string->SetModel(minValue);
   panel2->Add(string);
 
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
   panel2->Add(new Lum::Text(L"-"));
-  panel2->Add(new Lum::HSpace());
+  panel2->AddSpace();
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
@@ -222,8 +209,7 @@ void Preferences::PreInit()
 
   tab->Add(_(L"PREFS_LABEL_VALUES",L"Values"),label);
 
-  label=new Lum::Label();
-  label->SetFlex(true,true);
+  label=Lum::Label::Create(true,true);
 
   string=new Lum::String();
   string->SetMinWidth(Lum::Base::Size::stdCharWidth,4);
@@ -232,7 +218,7 @@ void Preferences::PreInit()
   string->SetModel(refValue);
   label->AddLabel(_(L"PREFS_LABEL_REF_VALUE",L"Reference for trend:"),string);
 
-  table=new Lum::Model::ListTable(1);
+  table=new Lum::Model::ListTable();
   table->AppendString(_(L"PREFS_LABEL_TREND_TYPE_REFREL",L"Relative to reference"));
   table->AppendString(_(L"PREFS_LABEL_TREND_TYPE_TWOWEEK",L"2 week trend"));
 
@@ -241,7 +227,7 @@ void Preferences::PreInit()
   combo->SetTableModel(table);
   label->AddLabel(_(L"PREFS_LABEL_TREND_TYPE",L"Trend type:"),combo);
 
-  table=new Lum::Model::ListTable(1);
+  table=new Lum::Model::ListTable();
   table->AppendString(_(L"PREFS_LABEL_TREND_DIR_DOWN",L"Lower is better"));
   table->AppendString(_(L"PREFS_LABEL_TREND_DIR_UP",L"Higher is better"));
 
@@ -253,12 +239,8 @@ void Preferences::PreInit()
   tab->Add(_(L"PREFS_LABEL_TREND",L"Trend"),label);
 
   panel->Add(tab);
-
-  panel->Add(new Lum::VSpace());
-
-  buttonRow=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
-  buttonRow->SetFlex(true,false);
-  panel->Add(buttonRow);
+  panel->AddSpace();
+  panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
 
   SetMain(panel);
 
